@@ -1,5 +1,5 @@
 package File::Dir::Dumper::Stream::JSON::Reader;
-$File::Dir::Dumper::Stream::JSON::Reader::VERSION = '0.6.0';
+$File::Dir::Dumper::Stream::JSON::Reader::VERSION = '0.6.1';
 use warnings;
 use strict;
 
@@ -94,7 +94,7 @@ File::Dir::Dumper::Stream::JSON::Reader - reader for stream of JSON objects.
 
 =head1 VERSION
 
-version 0.6.0
+version 0.6.1
 
 =head1 SYNOPSIS
 
@@ -125,48 +125,6 @@ Fetches the next object. Returns undef upon end of file.
 
 Shlomi Fish, C<< <shlomif@cpan.org> >>
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-file-dir-dumper at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Dir-Dumper>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc File::Dir::Dumper
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=File-Dir-Dumper>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/File-Dir-Dumper>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/File-Dir-Dumper>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/File-Dir-Dumper>
-
-=back
-
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008 Shlomi Fish, all rights reserved.
-
-This program is released under the following license: MIT/X11 Licence.
-
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
